@@ -4,6 +4,7 @@
 import datetime
 import io
 import logging
+import math
 import os
 import re
 import urllib.parse
@@ -44,6 +45,8 @@ _NUMBER_PARENTHESIS_PATTERN = r"\(\d+\)"
 _NON_WAYBACK_URLS: set[str] = {
     "https://www.sports-reference.com/cfb/boxscores/2025-01-20-notre-dame.html",
     "https://www.pro-football-reference.com/boxscores/202502090phi.htm",
+    "https://www.sports-reference.com/cfb/boxscores/2025-01-09-penn-state.html",
+    "https://www.sports-reference.com/cfb/boxscores/2024-12-31-alabama.html",
 }
 
 
@@ -519,6 +522,8 @@ def _find_new_dt(
                 venue_name = in_div_text.replace("Arena: ", "").strip()
             elif "Stadium:" in in_div_text:
                 venue_name = in_div_text.replace("Stadium: ", "").strip()
+            elif "Venue:" in in_div_text:
+                venue_name = in_div_text.replace("Venue: ", "").strip()
 
     scorebox_div = soup.find("div", class_="scorebox")
     if not isinstance(scorebox_div, Tag):
@@ -663,12 +668,15 @@ def _create_sportsreference_game_model(
         except ValueError as exc:
             session.cache.delete(urls=[url, response.url])
             logging.error(response.text)
+            logging.error(url)
             raise exc
 
     def _normalize_value(value: Any) -> Any:
         if isinstance(value, str):
             if "%" in value:
                 return float(value.replace("%", ""))
+        if isinstance(value, float) and math.isnan(value):
+            return None
         return value
 
     handle = io.StringIO()
@@ -1054,7 +1062,7 @@ def _create_sportsreference_game_model(
                 if "IP" in cols:
                     ips = df["IP"].tolist()
                     for idx, player in enumerate(players):
-                        innings_pitched[player] = _normalize_value(ips[idx])
+                        innings_pitched[player] = int(_normalize_value(ips[idx]))
                 if "ER" in cols:
                     ers = df["ER"].tolist()
                     for idx, player in enumerate(players):
@@ -1403,6 +1411,7 @@ def _create_sportsreference_game_model(
             .replace("Team", "")
             .replace("Arena:", "")
             .replace("Copyright", "")
+            .replace("Venue:", "")
         )
 
     try:
